# List of genome assemblies used to create the Prodigal training files

**Acinetobacter baumannii**: [GCF_008632635.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_008632635.1/)

**Campylobacter jejuni**: [GCF_000304375.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000304375.1)

**Enterococcus faecium**: [GCF_000174395.2](https://www.ncbi.nlm.nih.gov/assembly/GCF_000174395.2)

**Escherichia coli**: [GCF_000008865.2](https://www.ncbi.nlm.nih.gov/assembly/GCF_000008865.2/)

**Haemophilus influenzae**: [GCF_001856725.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_001856725.1)

**Legionella pneumophila**: [GCF_000008485.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000008485.1)

**Listeria monocytogenes**: [GCF_000196035.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000196035.1/)

**Salmonella enterica enteritidis**: [GCF_000009505.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000009505.1)

**Staphylococcus aureus**: [GCF_000012045.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000012045.1)

**Staphylococcus haemolyticus**: [GCF_000009865.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000009865.1)

**Streptococcus agalactiae**: [GCF_000007265.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000007265.1/)

**Streptococcus canis**: [GCF_900636575.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_900636575.1/)

**Streptococcus dysgalactiae**: [GCF_000317855.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000317855.1/)

**Streptococcus equi**: [GCF_000026605.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000026605.1/)

**Streptococcus pneumoniae**: [GCF_000006885.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000006885.1)

**Streptococcus pyogenes**: [GCF_000006785.2](https://www.ncbi.nlm.nih.gov/assembly/GCF_000006785.2/)

**Yersinia enterocolitica**: [GCF_000009345.1](https://www.ncbi.nlm.nih.gov/assembly/GCF_000009345.1)
